<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-dev',
'0_langue' => 'Brezhoneg [br]',
'0_liste' => 'spip-br@rezo.net',
'0_mainteneur' => 'Malo Morvan (malomorvan@yahoo.fr)',

// A
'access_interface_graphique' => 'Distrei&ntilde; d\'an etrefas grafek klok', # Gwelloc'h e vije ober gant etrefas evit trei&ntilde; interface; he&ntilde;veldra, grafek zo kalz komprenusoc'h eget kevrega&ntilde;. Dreist-holl e vez komprenet gant an holl hag en implij ema&ntilde; gant kalz a dud
'access_mode_texte' => 'diskouez an etrefas testenn eeun',
'admin_debug' => 'dizreina&ntilde;',
'admin_modifier_article' => 'Kemma&ntilde; ar pennad-ma&ntilde;',
'admin_modifier_auteur' => 'Kemma&ntilde; ar skridaozer-ma&ntilde;',
'admin_modifier_breve' => 'Kemma&ntilde; ar berrskrid-ma&ntilde;',
'admin_modifier_mot' => 'Kemma&ntilde; ar ger-stur-ma&ntilde;',
'admin_modifier_rubrique' => 'Kemma&ntilde; ar rubrikenn-ma&ntilde;',
'admin_recalculer' => 'Hizivaat ar bajenn',
'afficher_trad' => 'diskouez an troidigezhio&ugrave;',
'alerte_maj_impossible' => '<b>Diwallit&nbsp;!</b> N\'eus ket tu da hizivaat an diaz SQL etrezek ar stumm @version@, marteze abalamour d\'ur gudenn aotre evit kemma&ntilde; an diaz titouro&ugrave;. Mar plij kit e darempred gant ho herberc\'hier.',
'alerte_modif_info_concourante' => 'DIWALLIT : Kemmet eo bet an titour-ma&ntilde; en ul lec\'h all. Setu an talvoud nevez&nbsp;:',
'analyse_xml' => 'Dielfenna&ntilde; XML',
'annuler' => 'Nulla&ntilde;',
'antispam_champ_vide' => 'Na lakait netra ama&ntilde;&nbsp;:',
'articles_recents' => 'Pennado&ugrave; nevesa&ntilde;',
'avis_archive_incorrect' => 'N\'eo ket ar restr diell ur restr SPIP',
'avis_archive_invalide' => 'N\'eo ket reizh ar restr diell',
'avis_attention' => 'DIWALLIT&nbsp;!',
'avis_champ_incorrect_type_objet' => 'Anv maezienn direizh @name@ evit un draezenn a seurt @type@',
'avis_colonne_inexistante' => 'N\'eus ket eus ar bann @col@',
'avis_echec_syndication_01' => 'C\'hwitet eo bet ar sindikadur : dilennus eo ar backend kinniget, pe ne ginnig pennad ebet.',
'avis_echec_syndication_02' => 'C\'hwitet eo bet ar sindikadur : n\'eus ket tu da dizhout backend al lec\'hienn-ma&ntilde;.',
'avis_erreur' => 'Fazi: gwelet ama&ntilde; a-is',
'avis_erreur_connexion' => 'Fazi kevrea&ntilde;',
'avis_erreur_cookie' => 'kudenn toupin',
'avis_erreur_fonction_contexte' => 'Fazi programmi&ntilde;. Arabat d\'an arc\'hwel-ma&ntilde; beza&ntilde; galvet er gendestenn-ma&ntilde;.',
'avis_erreur_mysql' => 'Fazi SQL',
'avis_erreur_sauvegarde' => 'Fazi er savete (@type@ @id_objet@) !',
'avis_erreur_visiteur' => 'N\'eus ket tu da dizhout al lodenn brevez',

// B
'barre_a_accent_grave' => 'Ouzhpenna&ntilde; un A (pennlizherenn) gant un tired-boud warna&ntilde;',
'barre_aide' => 'Implijit ar berradenno&ugrave; tipografek evit pinvidikaat ar pajennaoza&ntilde;',
'barre_e_accent_aigu' => 'Ouzhpenna&ntilde; un E (pennlizherenn) gant un tired-lemm warna&ntilde;',
'barre_eo' => 'Ouzhpenna&ntilde; un E en \'O\' (munud)',
'barre_eo_maj' => 'Ouzhpenna&ntilde; un E en O (pennlizherenn)',
'barre_euro' => 'Ouzhpenna&ntilde; an arouezenn &euro;',
'barre_gras' => 'Lakaat e {{druz}}',
'barre_guillemets' => 'Gronna&ntilde; gant &laquo; krochedigo&ugrave; &raquo;',
'barre_guillemets_simples' => 'Gronna&ntilde; gant &#147;krochedigo&ugrave; a eil live&#148;',
'barre_intertitre' => 'Lakaat da {{{etretitl}}}',
'barre_italic' => 'Lakaat en {italek}',
'barre_lien' => 'Trei&ntilde; e [liamm gourskrid->http://...]',
'barre_lien_input' => 'Merkit chomlec\'h ho liamm (gallout a rit rei&ntilde; ar chomlec\'h a-stumm gant  http://www.forzhpetra/com pe rei&ntilde; niverenn ur pennad eus al lec\'hienn-ma&ntilde;).',
'barre_note' => 'Lakaat da [[Notenn trao&ntilde;-pajenn]]',
'barre_paragraphe' => 'Kroui&ntilde; ur rannbennad',
'barre_quote' => '<quote>Menegi&ntilde; ur gemennadenn</quote>',
'bouton_ajouter_document' => 'Ouzhpenna&ntilde; un teul',
'bouton_ajouter_image' => 'Ouzhpenna&ntilde; ur skeudenn',
'bouton_ajouter_image_document' => 'Ouzhpenna&ntilde; ur skeudenn pe&nbsp;un&nbsp;teul',
'bouton_changer' => 'Kemma&ntilde;',
'bouton_chercher' => 'Klask',
'bouton_choisir' => 'Dibab',
'bouton_download' => 'Pellgarga&ntilde;',
'bouton_enregistrer' => 'Enrolla&ntilde;',
'bouton_radio_desactiver_messagerie_interne' => 'Diweredekaat ar postelerezh diabarzh',
'bouton_radio_envoi_annonces' => 'Kas ar c\'hemenno&ugrave; embann',
'bouton_radio_non_envoi_annonces' => 'Chom hep kas kemenno&ugrave;',
'bouton_radio_non_envoi_liste_nouveautes' => 'Chom hep kas roll an nevezinti',
'bouton_recharger_page' => 'adkarga&ntilde; ar bajenn-ma&ntilde;',
'bouton_telecharger' => 'Pellgarga&ntilde;',
'bouton_valider' => 'Kadarnaat',

// C
'cal_apresmidi' => 'endervezh',
'cal_jour_entier' => 'devezh a-bezh',
'cal_matin' => 'beure',
'cal_par_jour' => 'deiziataer deiz-ha-deiz',
'cal_par_mois' => 'deiziataer miz-ha-miz',
'cal_par_semaine' => 'deiziataer sizhun-ha-sizhun',
'choix_couleur_interface' => 'liv',
'choix_interface' => 'dibab an etrefas',
'colonne' => 'Bann',
'confirm_changer_statut' => 'Diwallit, goulennet hoc\'h eus ma vo kemmet statud an elfenn-ma&ntilde;. Ha mennet oc\'h da genderc\'hel ?',
'correcte' => 'reizh',

// D
'date_aujourdhui' => 'hiziv',
'date_avant_jc' => 'kent J.K.',
'date_dans' => 'a-benn @delai@',
'date_de_mois_1' => '@j@ @nommois@',
'date_de_mois_10' => '@j@ @nommois@',
'date_de_mois_11' => '@j@ @nommois@',
'date_de_mois_12' => '@j@ @nommois@',
'date_de_mois_2' => '@j@ @nommois@',
'date_de_mois_3' => '@j@ @nommois@',
'date_de_mois_4' => '@j@ @nommois@',
'date_de_mois_5' => '@j@ @nommois@',
'date_de_mois_6' => '@j@ @nommois@',
'date_de_mois_7' => '@j@ @nommois@',
'date_de_mois_8' => '@j@ @nommois@',
'date_de_mois_9' => '@j@ @nommois@',
'date_demain' => 'warc\'hoazh',
'date_fmt_heures_minutes' => '@h@eur@m@munut',
'date_fmt_jour_heure' => '@jour@ da @heure@',
'date_fmt_jour_mois' => '@jour@ a viz @nommois@',
'date_fmt_jour_mois_annee' => '@jour@ a viz @nommois@ @annee@',
'date_fmt_mois_annee' => '@nommois@ @annee@',
'date_fmt_nomjour_date' => '@nomjour@ @date@',
'date_heures' => 'eur',
'date_hier' => 'dec\'h',
'date_il_y_a' => '@delai@ zo',
'date_jnum1' => '1a&ntilde;',
'date_jnum10' => '10',
'date_jnum11' => '11',
'date_jnum12' => '12',
'date_jnum13' => '13',
'date_jnum14' => '14',
'date_jnum15' => '15',
'date_jnum16' => '16',
'date_jnum17' => '17',
'date_jnum18' => '18',
'date_jnum19' => '19',
'date_jnum2' => 'eil',
'date_jnum20' => '20',
'date_jnum21' => '21',
'date_jnum22' => '22',
'date_jnum23' => '23',
'date_jnum24' => '24',
'date_jnum25' => '25',
'date_jnum26' => '26',
'date_jnum27' => '27',
'date_jnum28' => '28',
'date_jnum29' => '29',
'date_jnum3' => '3',
'date_jnum30' => '30',
'date_jnum31' => '31',
'date_jnum4' => '4',
'date_jnum5' => '5',
'date_jnum6' => '6',
'date_jnum7' => '7',
'date_jnum8' => '8',
'date_jnum9' => '9',
'date_jour_1' => 'Sul',
'date_jour_1_abbr' => 'Sul',
'date_jour_1_initiale' => 'S.',
'date_jour_2' => 'Lun',
'date_jour_2_abbr' => 'Lun',
'date_jour_2_initiale' => 'L.',
'date_jour_3' => 'Meurzh',
'date_jour_3_abbr' => 'Meu.',
'date_jour_3_initiale' => 'M.',
'date_jour_4' => 'Merc\'her',
'date_jour_4_abbr' => 'Mer.',
'date_jour_4_initiale' => 'M.',
'date_jour_5' => 'Yaou',
'date_jour_5_abbr' => 'Yaou',
'date_jour_5_initiale' => 'Y.',
'date_jour_6' => 'Gwener',
'date_jour_6_abbr' => 'Gwe.',
'date_jour_6_initiale' => 'Gw.',
'date_jour_7' => 'Sadorn',
'date_jour_7_abbr' => 'Sad.',
'date_jour_7_initiale' => 'S.',
'date_jours' => 'deiz',
'date_minutes' => 'munut',
'date_mois' => 'miz',
'date_mois_1' => 'Genver',
'date_mois_10' => 'Here',
'date_mois_11' => 'Du',
'date_mois_12' => 'Kerzu',
'date_mois_2' => 'C\'hwevrer',
'date_mois_3' => 'Meurzh',
'date_mois_4' => 'Ebrel',
'date_mois_5' => 'Mae',
'date_mois_6' => 'Mezheven',
'date_mois_7' => 'Gouere',
'date_mois_8' => 'Eost',
'date_mois_9' => 'Gwengolo',
'date_saison_1' => 'Goa&ntilde;v',
'date_saison_2' => 'nevez-amzer',
'date_saison_3' => 'ha&ntilde;v',
'date_saison_4' => 'diskar-amzer',
'date_secondes' => 'eilenn',
'date_semaines' => 'sizhun',
'date_un_mois' => 'miz',
'date_une_heure' => 'eur',
'date_une_minute' => 'munut',
'date_une_seconde' => 'eilenn',
'date_une_semaine' => 'sizhun',
'dirs_commencer' => 'a-benn kregi&ntilde; da vat gant ar staliadur',
'dirs_preliminaire' => 'A-raok kenderc\'hel : <b>Renka&ntilde; ar gwirio&ugrave; moned</b>',
'dirs_probleme_droits' => 'Kudenn gant ar gwirio&ugrave; moned',
'dirs_repertoires_absents' => '<p><b>N\'eo ket bet kavet ar c\'havlec\'hio&ugrave;-ma&ntilde; : </b></p><ul>@bad_dirs@.</ul>
  <p>Posupl eo e vefe abalamour d\'ur fazi impplij pennlizherenno&ugrave; pe lizherenno&ugrave; munut e lec\'hio&ugrave; fall.
  Gwiriit e klot mat stumm lizherenno&ugrave; ar c\'havlec\'hio&ugrave; gant ar pezh zo diskouezet a-us;
  ha ma ne glotont ket, adanvit anezho gant ho meziant FTP evit reizha&ntilde; ar gudenn.</p>
  <p>Ur wech graet an dra-se e c\'hellot </p>',
'dirs_repertoires_suivants' => '<p><b>N\'haller ket skriva&ntilde; er c\'havlec\'hio&ugrave;-ma&ntilde;&nbsp;: </b></p><ul>@bad_dirs@.</ul>
  <p>Implijit ar meziant FTP a-benn kemma&ntilde; ar gwirio&ugrave; evit pep hini.
  Displeget eo an hentenn er sturlevr stalia&ntilde;.</p>
  <p>Ur wech graet se e c\'helloc\'h ',
'double_occurrence' => '@balise@ bet kavet div wech',

// E
'en_cours' => 'war ober',
'entree_dimensions' => 'Ment&nbsp;:',
'entree_titre_document' => 'Titl an teul&nbsp;:',
'entree_titre_image' => 'Titl ar skeudenn&nbsp;:',
'envoi_via_le_site' => 'Kas dre al lec\'hienn',
'erreur' => 'Fazi',
'erreur_balise_non_fermee' => 'Balizenn ziwezha&ntilde; chomet digor :',
'erreur_texte' => 'fazi',
'etape' => 'Pazenn',

// F
'fichier_introuvable' => 'Restr @fichier@ dibosupl da gavout',
'form_auteur_confirmation' => 'Confirmez votre adresse email', # NEW
'form_auteur_email_modifie' => 'Votre adresse email a &eacute;t&eacute; modifi&eacute;e.', # NEW
'form_auteur_envoi_mail_confirmation' => 'Un courrier &eacute;lectronique de confirmation vient d\'&ecirc;tre envoy&eacute; &agrave; @email@. Vous devrez visiter l\'adresse Web mentionn&eacute;e dans ce courrier pour valider votre adresse mail.', # NEW
'form_auteur_mail_confirmation' => 'Bonjour,

Vous avez demand&eacute; &agrave; changer votre adresse email.
Pour confirmer votre nouvelle adresse, il suffit de vous connecter &agrave;
l\'adresse ci-dessous (dans le cas contraire, votre demande
sera ignor&eacute;e) :

    @url@
', # NEW
'form_deja_inscrit' => 'Enskrivet oc\'h c\'hoazh.',
'form_email_non_valide' => 'N\'eo ket reizh ho postel.',
'form_forum_access_refuse' => 'N\'oc\'h ket aotreet da vont war al lec\'hienn-ma&ntilde; ken.',
'form_forum_bonjour' => 'Demat @nom@,',
'form_forum_email_deja_enregistre' => 'Enrollet eo ar postel-se dija. Gallout a rit ober gant ho ker-tremen boas neuze.',
'form_forum_identifiant_mail' => 'Ema&ntilde; ho kod moned nevez o paouez beza&ntilde; kaset deoc\'h dre bostel.',
'form_forum_identifiants' => 'Titouro&ugrave; hiniennel',
'form_forum_indiquer_nom_email' => 'Skrivit ama&ntilde; hoc\'h anv hag ho postel. Kaset e vo deoc\'h buan ho titouro&ugrave; hiniennel dre bostel.',
'form_forum_login' => 'Kod kevrea&ntilde; :',
'form_forum_message_auto' => '(ur gemennadenn emgefre eo homa&ntilde;)',
'form_forum_pass' => 'ger-tremen :',
'form_forum_probleme_mail' => 'Kudenn postel&nbsp;: n\'haller ket kas an titouro&ugrave;.',
'form_forum_voici1' => 'Setu ho titouro&ugrave; evit gallout kemer perzh e buhez "@nom_site_spip@" (@adresse_site@) :',
'form_forum_voici2' => 'Setu ho titouro&ugrave; evit gallout kinnig pennado&ugrave; war "@nom_site_spip@" (@adresse_login@) :',
'form_indiquer_email' => 'Skrivit ho postel mar plij.',
'form_indiquer_nom' => 'Skrivit hoc\'h anv mar plij.',
'form_indiquer_nom_site' => 'Skrivit anv ho lec\'hienn.',
'form_pet_adresse_site' => 'Chomlec\'h ho lec\'hienn',
'form_pet_aucune_signature' => 'Sinadur ebet ne glot gant ar c\'hod-ma&ntilde;...',
'form_pet_confirmation' => 'Kadarnait ho sinadur mar-plij :',
'form_pet_deja_enregistre' => 'Enrollet eo al lec\'hienn-ma&ntilde; c\'hoazh',
'form_pet_deja_signe' => 'Sinet eo bet an destenn-se ganeoc\'h c\'hoazh.',
'form_pet_envoi_mail_confirmation' => 'Emeur o paouez kas ur postel gwiria&ntilde; da @email@. Ret e vo deoc\'h gweladenni&ntilde; ar chomlec\'h meneget er postel-se a-benn kadarnaat ho sinadur.',
'form_pet_mail_confirmation' => 'Demat, 

Goulennet hoc\'h eus sina&ntilde; ar sinadeg :
@titre@.

An titouro&ugrave;-ma&ntilde; zo bet roet ganeoc\'h :
    Anv: @nom_email@
    Lec\'hienn: @nom_site@ - @url_site@
@message@

POUEZUS...
Evit kadarnaat ho sinadur eo trawalc\'h deoc\'h mont d\'ar chomlec\'h ama&ntilde; dindan
(ma ne rit ket se, ne vo ket ouzhpennet ho sinadur) :

    @url@


Trugarez da gemer perzh
',
'form_pet_message_commentaire' => 'Ur gemennadenn, un evezhiadenn&nbsp;?',
'form_pet_nom_site2' => 'Anv ho lec\'hienn',
'form_pet_probleme_liens' => 'Savit ho kemennadenn en-dro en ur denna&ntilde; ar gourliammo&ugrave; zo enni. ',
'form_pet_probleme_technique' => 'Ur gudenn deknikel zo, n\'haller ket sina&ntilde; evit ar poent.',
'form_pet_signature_pasprise' => 'N\'eus ket bet dalc\'het kont eus ho sinadur.',
'form_pet_signature_validee' => 'Kadarnet eo bet ho sinadur. Trugarez&nbsp;!',
'form_pet_site_deja_enregistre' => 'Enrollet eo bet al lec\'hienn-ma&ntilde; c\'hoazh',
'form_pet_url_invalide' => 'Direizh eo an URL bet merket ganeoc\'h.',
'form_pet_votre_email' => 'Ho chomlec\'h postel',
'form_pet_votre_nom' => 'Hoc\'h anv pe lesanv',
'form_pet_votre_site' => 'M\'ho peus ul lec\'hienn Web e c\'hellit he mennegi&ntilde; ama&ntilde; da-heul',
'form_prop_confirmer_envoi' => 'Kadarnaat ar c\'has',
'form_prop_description' => 'Deskrivadur/evezhiadenn',
'form_prop_enregistre' => 'Enrollet eo bet ho kinnig. Embannet e vo goude beza&ntilde; bet asantet gant tud e-karg eus al lec\'hienn-ma&ntilde;.',
'form_prop_envoyer' => 'Kas ur gemennadenn',
'form_prop_indiquer_email' => 'Merkit ur postel reizh mar plij',
'form_prop_indiquer_nom_site' => 'Merkit anv al lec\'hienn.',
'form_prop_indiquer_sujet' => 'Merkit ur sujed',
'form_prop_message_envoye' => 'Kaset eo bet ar gemennadenn',
'form_prop_nom_site' => 'Anv al lec\'hienn',
'form_prop_non_enregistre' => 'N\'eo ket bet enrollet ho kinnig',
'form_prop_sujet' => 'Sujed',
'form_prop_url_site' => 'Chomlec\'h (URL) al lec\'hienn',
'forum_acces_refuse' => 'N\'oc\'h ket aotreet da vont war ar foromo&ugrave;-ma&ntilde; ken .',
'forum_attention_dix_caracteres' => '<b>Diwallit&nbsp;!</b> Dek arouezenn d\'an nebeuta&ntilde; a rank beza&ntilde; en ho kemennadenn.',
'forum_attention_trois_caracteres' => '<b>Diwallit&nbsp;!</b> Teir arouezenn d\'an nebeuta&ntilde; a rank beza&ntilde; en ho titl.',
'forum_attention_trop_caracteres' => '<b>Diwallit&nbsp;!</b> re hir eo ho kemennadenn (@compte@ arouez)&nbsp;: arabat e vefe ouzhpenn @max@ arouezenn enni evit gallout beza&ntilde; kaset.',
'forum_avez_selectionne' => 'Diuzet hoc\'h eus&nbsp;:',
'forum_cliquer_retour' => 'Klikit <a href=\'@retour_forum@\'>ama&ntilde;</a> evit kenderc\'hel.',
'forum_forum' => 'forom',
'forum_info_modere' => 'Habaskaet eo ar forom-ma&ntilde; a-raok embann ar pennado&ugrave;&nbsp;: ne vo ket gwelet ho kemennadenn a-raok na vefe lennet hag asantet gant unan eus merourien al lec\'hienn.',
'forum_lien_hyper' => '<b>liamm gourskrid</b> (Diret)',
'forum_message_definitif' => 'Kemennadenn echu : kas d\'al lec\'hienn',
'forum_message_trop_long' => 'Re hir eo ho kemennadenn. 20000 arouezenn a c\'heller lakaat d\'ar muia&ntilde;.',
'forum_ne_repondez_pas' => 'Na respontit ket d\'ar postel-ma&ntilde;, met war ar forom, d\'ar chomlec\'h da-heul :',
'forum_non_inscrit' => 'N\'oc\'h ket enskrivet, pe direizh eo ar ger-tremen pe ar chomlec\'h.',
'forum_page_url' => '(Ma ra ho kemmennadenn anv eus ur pennad all war Internet pe eus ur bajenn warni muioc\'h a ditouro&ugrave; e c\'hellit skriva&ntilde; ama&ntilde; goude titl ar bajenn hag ar chomlec\'h anezhi.)',
'forum_par_auteur' => 'gant @auteur@',
'forum_poste_par' => 'Kemennadenn kaset @parauteur@ da-heul ar pennad &laquo; @titre@ &raquo;.',
'forum_probleme_database' => 'Kudenn diaz titouro&ugrave;, n\'eo ket bet enrollet ho kemennadenn.',
'forum_qui_etes_vous' => '<b>Piv oc\'h-hu ?</b> (Diret)',
'forum_texte' => 'Testenn ho kemennadenn :',
'forum_titre' => 'Titl :',
'forum_titre_erreur' => 'Fazi...',
'forum_url' => 'URL :',
'forum_valider' => 'Kadarnaat an dibab-ma&ntilde;',
'forum_voir_avant' => 'Rakwelet ar gemennadenn a-raok kas anezhi',
'forum_votre_email' => 'Ho postel :',
'forum_votre_nom' => 'Hoc\'h anv (pe lesanv) :',
'forum_vous_enregistrer' => 'Evit kemer perzh er forom-ma&ntilde; e rankit beza&ntilde; enrollet en a-raok.
  Trugarez da skriva&ntilde; ama&ntilde; dindan an titouro&ugrave; hiniennel zo bet roet deoc\'h.
  Ma n\'oc\'h ket enrollet c\'hoazh e rankit ',
'forum_vous_inscrire' => 'en em enskriva&ntilde;.',

// I
'ical_texte_rss_articles' => 'D\'ar chomlec\'h-ma&ntilde; ema&ntilde; restr &laquo;backend&raquo; ar pennado&ugrave; :',
'ical_texte_rss_articles2' => 'Gallout a rit kaout restro&ugrave; &laquo;backend&raquo; evit pennado&ugrave; pep rummad al lec\'hienn ivez :',
'ical_texte_rss_breves' => 'Bez\' ez eus ivez ur restr enni berrskrido&ugrave; al lec\'hienn. Ma resisait niverenn ur rubrikenn, n\'ho po nemet berrskrido&ugrave; ar rubrikenn-se.',
'icone_a_suivre' => 'Da genderc\'hel',
'icone_admin_site' => 'Mera&ntilde; al lec\'hienn',
'icone_agenda' => 'Deiziataer',
'icone_aide_ligne' => 'Skoazell',
'icone_articles' => 'Pennado&ugrave;',
'icone_auteurs' => 'Skridaozerien',
'icone_breves' => 'Berrskrido&ugrave;',
'icone_brouteur' => 'Merdei&ntilde; prim',
'icone_configuration_site' => 'Keflunia&ntilde; ',
'icone_configurer_site' => 'Keflunia&ntilde; ho lec\'hienn',
'icone_creer_nouvel_auteur' => 'Kroui&ntilde; ur skridaozer nevez',
'icone_creer_rubrique' => 'Kroui&ntilde; ur rubrikenn',
'icone_creer_sous_rubrique' => 'Kroui&ntilde; un isrubrikenn',
'icone_deconnecter' => 'Digevrea&ntilde;',
'icone_discussions' => 'Kaozeadenno&ugrave;',
'icone_doc_rubrique' => 'Teulio&ugrave; ar rubrikenno&ugrave;',
'icone_ecrire_article' => 'Skriva&ntilde; ur pennad nevez',
'icone_edition_site' => 'Embann',
'icone_forum_administrateur' => 'Forom ar verourien',
'icone_forum_suivi' => 'Heulia&ntilde; ar foromo&ugrave;',
'icone_gestion_langues' => 'Mera&ntilde; ar yezho&ugrave;',
'icone_informations_personnelles' => 'Titouro&ugrave; hiniennel',
'icone_interface_complet' => 'Etrefas klok',
'icone_interface_simple' => 'Etrefas eeunaet',
'icone_maintenance_site' => 'Ober war-dro al lec\'hienn',
'icone_messagerie_personnelle' => 'Postelerezh hiniennel',
'icone_mots_cles' => 'Gerio&ugrave;-stur',
'icone_nouvelle_breve' => 'Skriva&ntilde; ur berrskrid nevez',
'icone_repartition_actuelle' => 'Diskouez an dasparzh er mare-ma&ntilde;',
'icone_repartition_debut' => 'Diskouez an dasparzh abaoe an dero&ugrave;',
'icone_repartition_visites' => 'Dasparzh ar gweladenno&ugrave;',
'icone_rubriques' => 'Rubrikenno&ugrave;',
'icone_sauver_site' => 'Savetei&ntilde; al lec\'hienn',
'icone_site_entier' => 'Al lec\'hienn a-bezh',
'icone_sites_references' => 'Lec\'hienno&ugrave; menegeret',
'icone_statistiques' => 'Stadego&ugrave; al lec\'hienn',
'icone_statistiques_visites' => 'Stadego&ugrave;',
'icone_suivi_activite' => 'Heulia&ntilde; buhez al lec\'hienn',
'icone_suivi_actualite' => 'Emdroadur al lec\'hienn',
'icone_suivi_forums' => 'Heulia&ntilde;/mera&ntilde; ar foromo&ugrave;',
'icone_suivi_pettions' => 'Heulia&ntilde;/mera&ntilde; ar sinadego&ugrave;',
'icone_suivi_revisions' => 'Kemmo&ugrave; ar pennado&ugrave;',
'icone_supprimer_document' => 'Diverka&ntilde; an teul-ma&ntilde;',
'icone_supprimer_image' => 'Diverka&ntilde; ar skeudenn-ma&ntilde;',
'icone_supprimer_message' => 'Diverka&ntilde; ar gemennadenn-ma&ntilde;',
'icone_tous_articles' => 'Ho holl bennado&ugrave;',
'icone_tous_auteur' => 'An holl skridaozerien',
'icone_valider_message' => 'Asanti&ntilde; d\'ar gemennadenn-ma&ntilde;',
'icone_visiter_site' => 'Gweladenni&ntilde;',
'icone_voir_en_ligne' => 'Gwelet enlinenn',
'image_tourner_180' => 'Trei&ntilde; da 180 derez',
'image_tourner_droite' => 'Trei&ntilde; da 90 derez war an tu dehou',
'image_tourner_gauche' => 'Trei&ntilde; da 90 derez war an tu kleiz',
'img_indisponible' => 'skeudenn dibosupl da gaout',
'impossible' => 'dibosupl',
'info_a_suivre' => 'DA GENDERC\'HEL&raquo;',
'info_a_valider' => '[da wiria&ntilde;]',
'info_acces_interdit' => 'Difennet mont tre',
'info_acces_refuse' => 'Nac\'het eo bet deoc\'h mon tre',
'info_action' => 'Oberiadenn : @action@',
'info_administrer_rubriques' => 'Gallout a rit mera&ntilde; ar rubrikenn-ma&ntilde; hag an isrubrikenndo&ugrave; enni',
'info_adresse_non_indiquee' => 'N\'hoc\'h eus ket lakaet chomlec\'h ebet da arnodi&ntilde;&nbsp;!',
'info_aide' => 'SKOAZELL :',
'info_ajouter_mot' => 'Ouzhpenna&ntilde; ar ger-ma&ntilde;',
'info_annonce' => 'KEMENN',
'info_annonces_generales' => 'Kemenno&ugrave; hollek&nbsp;:',
'info_article_propose' => 'Pennad kinniget',
'info_article_publie' => 'Pennad embannet',
'info_article_redaction' => 'Pennad emeur o skridaoza&ntilde;',
'info_article_refuse' => 'Pennad nac\'het',
'info_article_supprime' => 'Pennad diverket',
'info_articles' => 'Pennado&ugrave;',
'info_articles_a_valider' => 'Ar pennado&ugrave; da gadarnaat',
'info_articles_nb' => '@nb@ articles', # NEW
'info_articles_proposes' => 'Pennado&ugrave; kinniget',
'info_articles_un' => '1 article', # NEW
'info_auteurs_nombre' => 'skridaozer(ien)&nbsp;:',
'info_authentification_ftp' => 'Gwiria&ntilde; (dre FTP).',
'info_bloquer_lien' => 'Stanka&ntilde; al liamm-ma&ntilde;',
'info_breves_02' => 'Berrskrido&ugrave;',
'info_breves_2' => 'berrskrido&ugrave;',
'info_breves_nb' => '@nb@ br&egrave;ves', # NEW
'info_breves_un' => '1 br&egrave;ve', # NEW
'info_breves_valider' => 'Berrskrido&ugrave; da gadarnaat',
'info_connexion_refusee' => 'Kevrea&ntilde; nac\'het',
'info_contact_developpeur' => 'Kit e darempred gant un diorroer.',
'info_contenance' => 'El lec\'hienn-ma&ntilde; ez eus&nbsp;:',
'info_contribution' => 'kemennadenn er forom',
'info_copyright' => 'Ur meziant dieub eo @spip@, dasparzhet @lien_gpl@.',
'info_copyright_doc' => 'Evit titouro&ugrave; ouzhpenn, gwelet al lec\'hienn <a href="@spipnet@">http://www.spip.net/fr</a>.',
'info_copyright_gpl' => 'dindan aotre implijout GPL',
'info_cours_edition' => 'Ar pennado&ugrave; emaoc\'h o skriva&ntilde;',
'info_creer_repertoire' => 'Krouit ur restr pe ur c\'havlec\'h anvet&nbsp;:',
'info_creer_repertoire_2' => 'en iskavlec\'h <b>@repertoire@</b>, ha&nbsp;:',
'info_creer_vignette' => 'kroui&ntilde; emgefreek ar skeudennig',
'info_deplier' => 'Displega&ntilde;',
'info_descriptif_nombre' => 'deskrivadur(io&ugrave;)&nbsp;:',
'info_description' => 'Deskrivadur&nbsp;:',
'info_description_2' => 'Deskrivadur&nbsp;:',
'info_dimension' => 'Ment&nbsp;:',
'info_document' => 'Teul',
'info_document_indisponible' => 'N\'eo ket hegerz an teul-ma&ntilde;',
'info_documents' => 'Teulio&ugrave;',
'info_documents_nb' => '@nb@ documents', # NEW
'info_documents_un' => '1 document', # NEW
'info_echange_message' => 'SPIP a ginnig eskemm kemennadenno&ugrave; ha sevel foromo&ugrave; prevez etre izili al lec\'hienn. Gallout a rit ober gant ar servij-ma&ntilde;, pe get.',
'info_ecire_message_prive' => 'Skriva&ntilde; ur gerig prevez;',
'info_email_invalide' => 'Postel direizh.',
'info_en_cours_validation' => 'Ar pennado&ugrave; emaoc\'h o skriva&ntilde;',
'info_en_ligne' => 'Enlinenn evit poent&nbsp;:',
'info_envoyer_message_prive' => 'Kas ur gerig prevez d\'ar skridaozer-ma&ntilde;',
'info_erreur_requete' => 'Fazi er reked :',
'info_erreur_squelette2' => 'N\'eus framm <b>@fichier@</b> ebet da gaout...',
'info_erreur_systeme' => 'Fazi reizhiad (errno @errsys@)',
'info_erreur_systeme2' => 'Marteze eo leun-chouk ar bladenn-galet, pe neuze eo mazaouet an diaz titouro&ugrave;. <br />
 <font color=\'red\'>Klaskit <a href=\'@script@\'>ratrea&ntilde; an diaz</a>,
 pe kit e darempred gant an herberc\'hier.</font>',
'info_fini' => 'Echu eo !',
'info_format_image' => 'Furmado&ugrave; skeudenn a c\'hell beza&ntilde; implijet da sevel skeudennigo&ugrave;&nbsp;: @gd_formats@.',
'info_format_non_defini' => 'Stumm didermenet',
'info_grand_ecran' => 'Skramm bras',
'info_image_aide' => 'SKOAZELL',
'info_image_process_titre' => 'Hentenn da groui&ntilde; skeudennigo&ugrave;',
'info_impossible_lire_page' => '<b>Fazi !</b> Dibosupl eo lenn ar bajenn <tt><html>@test_proxy@</html></tt> dre ar proksi',
'info_inclusion_directe' => 'Enkloza&ntilde; war-eeun:',
'info_inclusion_vignette' => 'Enkloza&ntilde; ar skeudennig&nbsp;:',
'info_installation_systeme_publication' => 'O stalia&ntilde; ar reizhiad embann...',
'info_installer_documents' => 'Gallout a rit stalia&ntilde; en un doare emgefreek an holl deulio&ugrave; zo en teuliad @upload@.',
'info_installer_ftp' => 'Dre ma\'z oc\'h merour e c\'hellit stalia&ntilde; restro&ugrave; (dre FTP) en teuliad @upload@ deoc\'h da c\'hallout ober ganto ama&ntilde; da c\'houde.',
'info_installer_images' => 'Er furmado&ugrave; JPEG, GIF ha PNG e c\'hellit stalia&ntilde; skeudenno&ugrave;.',
'info_installer_images_dossier' => 'Stalia&ntilde; skeudenno&ugrave; en teuliad @upload@ evit gallout o diuza&ntilde; ama&ntilde;.',
'info_installer_tous_documents' => 'Stalia&ntilde; an holl deulio&ugrave;',
'info_interface_complete' => 'Etrefas klok',
'info_interface_simple' => 'Etrefas eeunaet',
'info_joindre_document_article' => 'Teulio&ugrave; a eurt-se a c\'hellit staga&ntilde; ouzh ar pennad-ma&ntilde; :',
'info_joindre_document_rubrique' => 'Teulio&ugrave; a seurt-se a c\'hellit staga&ntilde; ouzh ar rubrikenn-ma&ntilde; :',
'info_joindre_documents_article' => 'Teulio&ugrave; a seurt-se a c\'hellit staga&ntilde; ouzh ho pennad&nbsp;:',
'info_l_article' => 'ar pennad',
'info_la_breve' => 'ar berrskrid',
'info_la_rubrique' => 'ar rubrikenn',
'info_langue_principale' => 'Yezh penna&ntilde; al lec\'hienn',
'info_largeur_vignette' => '@largeur_vignette@ &times; @hauteur_vignette@ piksel',
'info_les_auteurs_1' => 'gant @les_auteurs@',
'info_logo_format_interdit' => 'Er furmad @formats@ hepken e vez aotreet al logoio&ugrave;.',
'info_logo_max_poids' => 'Nebeutoc\'h eget @maxi@ e rank al logoio&ugrave; beza&ntilde; (@actuel@ eo ar restr-ma&ntilde;).',
'info_logo_max_taille' => 'Bihanoc\'h eget @maxi@ e rank al logoio&ugrave; beza&ntilde; (@actuel@ eo ar restr-ma&ntilde;).',
'info_mail_fournisseur' => 'hoc\'hanv@herberc\'hier.com',
'info_message_2' => 'KEMENNADENN',
'info_message_supprime' => 'KEMENNADENN BET DIVERKET',
'info_messages_nb' => '@nb@ messages', # NEW
'info_messages_un' => '1 message', # NEW
'info_mise_en_ligne' => 'Lakaet war ar rouedad d\'an&nbsp;:',
'info_modification_parametres_securite' => 'kemm an arventenno&ugrave; surentez',
'info_mois_courant' => 'E-kerzh ar miz :',
'info_mot_cle_ajoute' => 'Ar ger-stur-ma&ntilde; zo bet ouzhpennet',
'info_multi_herit' => 'Yezh dre ziouer',
'info_multi_langues_soulignees' => 'Ar <u>yezho&ugrave; islinennet</u> zo bet troet holl destenno&ugrave; an etrefas enne. Ma tibabit ar yezho&ugrave;-se e vo troet o-unan ul lodenn vat eus elfenno&ugrave; al lec\'hienn (deiziado&ugrave;, furmskrido&ugrave;, hag all). Evit ar yezho&ugrave; n\'int ket islinennet e vo an elfenno&ugrave;-se e yezh penna&ntilde; al lec\'hienn.',
'info_multilinguisme' => 'Liesyezhegezh',
'info_nom_non_utilisateurs_connectes' => 'N\'ema&ntilde; ket hoc\'h  anv war roll an implijerien kevreet.',
'info_nom_utilisateurs_connectes' => 'Gwelet e vez hoc\'h anv war roll an implijerien kevreet.',
'info_nombre_en_ligne' => 'Brema&ntilde; war al lec\'hienn&nbsp;:',
'info_non_resultat' => 'Disoc\'h ebet evit "@cherche_mot@"',
'info_non_utilisation_messagerie' => 'N\'implijit ket postelerezh diabarzh al lec\'hienn-ma&ntilde;.',
'info_nouveau_message' => 'UR GEMENNADENN NEVEZ HOC\'H EUS BET',
'info_nouveaux_messages' => '@total_messages@ KEMENNADENN NEVEZ HOC\'H EUS BET',
'info_numero_abbreviation' => 'Niv.&nbsp;',
'info_obligatoire' => 'Ret eo deoc\'h rei&ntilde; an titour-ma&ntilde;',
'info_panne_site_syndique' => 'Sac\'het eo al lec\'hienn sindikadet',
'info_pense_bete' => 'NOTENNIG-E&Ntilde;VOR',
'info_petit_ecran' => 'Skramm bihan',
'info_petition_close' => 'Kloz eo ar sinadeg',
'info_pixels' => 'piksel',
'info_plusieurs_mots_trouves' => 'Meur a c\'her-stur zo bet kavet evit "@cherche_mot@":',
'info_popularite_5' => 'brud;&nbsp;:',
'info_portfolio' => 'Portfolio',
'info_portfolio_automatique' => 'Portfolio emgefre&nbsp;:',
'info_premier_resultat' => '[@debut_limit@ disoc\'h kenta&ntilde; diwar @total@]',
'info_premier_resultat_sur' => '[@debut_limit@ disoc\'h kenta&ntilde; diwar @total@]',
'info_probleme_grave' => 'kudenn a',
'info_propose_1' => '[@nom_site_spip@] a ginnig : @titre@',
'info_propose_2' => 'Pennad bet kinniget
---------------',
'info_propose_3' => 'Kinnig a reer embann ar pennad "@titre@".',
'info_propose_4' => 'Pedet oc\'h da zont d\'e lenn ha da rei&ntilde; hoc\'h ali',
'info_propose_5' => 'er forom stag outa&ntilde;. Kavet e vo er chomlec\'h-ma&ntilde; :',
'info_publie_01' => 'Kadarnaet eo bet ar pennad "@titre@" gant @connect_nom@.',
'info_publie_1' => '[@nom_site_spip@] A EMBANN : @titre@',
'info_publie_2' => 'Pennad embannet
--------------',
'info_rechercher' => 'Klask',
'info_rechercher_02' => 'Klask&nbsp;:',
'info_remplacer_vignette' => 'Erlec\'hia&ntilde; ar skeudennig dre ziouer gant ul logo deoc\'h&nbsp;:',
'info_retablir_lien' => 'adlakaat al liamm-ma&ntilde;',
'info_retirer_mot' => 'Tenna&ntilde; ar ger-ma&ntilde;',
'info_retirer_mots' => 'Tenna&ntilde; an holl c\'herio&ugrave;',
'info_rubriques_nb' => '@nb@ rubriques', # NEW
'info_rubriques_un' => '1 rubrique', # NEW
'info_sans_titre_2' => 'titl ebet',
'info_selectionner_fichier' => 'Gallout a rit diuza&ntilde; ur restr eus an teuliad @upload@',
'info_selectionner_fichier_2' => 'Diuza&ntilde; ur restr&nbsp;:',
'info_signature_supprimee' => 'Diverket eo bet ar sinadur',
'info_signature_supprimee_erreur' => 'Fazi&nbsp;: ne glot ar c\'hod diverka&ntilde;-ma&ntilde; gant sinadur ebet.',
'info_site_attente' => 'Lec\'hienn a c\'hortoz beza&ntilde; kadarnaet',
'info_site_reference' => 'Lec\'hienn menegeret enlinenn',
'info_site_refuse' => 'Lec\'hienn bet nac\'het',
'info_sites_nb' => '@nb@ sites', # NEW
'info_sites_referencer' => 'Menegeri&ntilde; ul lec\'hienn',
'info_sites_un' => '1 site', # NEW
'info_supprimer_vignette' => 'diverka&ntilde; ar skeudennig',
'info_symbole_bleu' => 'Talvezout a ra an arouez <b>glas</b> evit un <b>notennig-e&ntilde;vor</b>: da lavaret eo ur gemennadenn evidoc\'h hepken.',
'info_symbole_jaune' => 'Talvezout a ra an arouez <b>melen</b> evit ur <b>c\'hemenn d\'an holl skridaozerien</b>&nbsp;: a c\'hell beza&ntilde; kemmet gant ur merour ha lennet gant an holl skridaozerien.',
'info_symbole_vert' => 'Talvezout a ra an arouez <b>gwer</b> evit ar <b>c\'hemennadenno&ugrave; bet eskemmet etre implijerien all</b> al lec\'hienn.',
'info_syndication' => 'Sindikadur&nbsp;:',
'info_syndication_articles' => 'pennad(o&ugrave;)',
'info_telecharger' => 'Pellgarga&ntilde; adal hoc\'h urzhiataer&nbsp;:',
'info_telecharger_nouveau_logo' => 'Pellgarga&ntilde; ul logo nevez&nbsp;:',
'info_telecharger_ordinateur' => 'Pellgarga&ntilde; adal hoc\'h urzhiataer&nbsp;:',
'info_tous_resultats_enregistres' => '[enrollet e vez an holl discoc\'ho&ugrave;]',
'info_tout_afficher' => 'Diskouez pep tra',
'info_travaux_texte' => 'N\'eo ket bet kefluniet al lec\'hienn evit c\'hoazh. Distroit a-benn nebeut...',
'info_travaux_titre' => 'Emeur o sevel al lec\'hienn',
'info_trop_resultat' => 'Re a zisoc\'ho&ugrave; evit "@cherche_mot@"; resisait termeno&ugrave; hoc\'h enklask mar plij.',
'info_utilisation_messagerie_interne' => 'Ober a rit gant postelerezh diabarzh al lec\'hienn-ma&ntilde;.',
'info_valider_lien' => 'kadarnaat al liamm-ma&ntilde;',
'info_verifier_image' => 'gwiriit eo bet treuzkaset mat ho skeudenno&ugrave;.',
'info_vignette_defaut' => 'Skeudennig dre ziouer',
'info_vignette_personnalisee' => 'skeudennig personelaet',
'info_visite' => 'gweladenn :',
'info_visites' => 'gweladenn :',
'info_vos_rendez_vous' => 'Hoc\'h emgavio&ugrave; da zont',
'info_zoom' => 'zoum',
'infos_vos_pense_bete' => 'Ho notennigo&ugrave;-e&ntilde;vor', # MODIF
'item_breve_proposee' => 'Berrskrid bet kinniget',

// L
'lien_afficher_icones_seuls' => 'Diskouez ar skeudennigo&ugrave; hepken',
'lien_afficher_texte_icones' => 'Diskouez ar skeudennigo&ugrave; hag an destenn',
'lien_afficher_texte_seul' => 'Diskouez an destenn hepken',
'lien_liberer' => 'dieubi&ntilde;',
'lien_liberer_tous' => 'dieubi&ntilde; ar pennado&ugrave;-ma&ntilde;',
'lien_nouvea_pense_bete' => 'NOTENNIG-E&Ntilde;VOR NEVEZ',
'lien_nouveau_message' => 'KEMENNADENN NEVEZ',
'lien_nouvelle_annonce' => 'KEMENN NEVEZ',
'lien_petitions' => 'SINADEG',
'lien_popularite' => 'brud&nbsp;: @popularite@%',
'lien_racine_site' => 'GWRIZIENN AL LEC\'HIENN',
'lien_reessayer' => 'klask en-dro',
'lien_repondre_message' => 'Repont d\'ar gemennadenn-ma&ntilde;',
'lien_supprimer' => 'diverka&ntilde;',
'lien_tout_afficher' => 'Diskouez pep tra',
'lien_visite_site' => 'gweladenni&ntilde; al lec\'hienn-ma&ntilde;',
'lien_visites' => '@visites@&nbsp;gweladenn',
'lien_voir_auteur' => 'Gwelet ar skridaozer-ma&ntilde;',
'ligne' => 'Linenn',
'login' => 'Kevrea&ntilde;',
'login_acces_prive' => 'tizhout al lodenn brevez',
'login_autre_identifiant' => 'Kevrea&ntilde; gant ur c\'hod anaout all',
'login_cookie_accepte' => 'Grit ar pezh zo ezhomm evit ma vint degemeret gant ho merdeer, evit al lec\'hienn-ma&ntilde; d\'an nebeuta&ntilde;',
'login_cookie_oblige' => 'Evit kevrea&ntilde; en un doare sur war al lec\'hienn-ma&ntilde; e rankit degemer an toupino&ugrave;.',
'login_deconnexion_ok' => 'Digevreet oc\'h.',
'login_erreur_pass' => 'Fazi ger-tremen.',
'login_espace_prive' => 'lodenn brevez',
'login_identifiant_inconnu' => 'N\'eo ket anavezet ar c\'hoad anaout &laquo; @login@ &raquo;.',
'login_login' => 'Kod kevrea&ntilde; :',
'login_login2' => 'Kod kevrea&ntilde; (kod anaout evit kevrea&ntilde; ouzh al lec\'hienn)&nbsp;:',
'login_login_pass_incorrect' => '(direizh eo ar c\'hod kevrea&ntilde; pe ar ger-tremen)',
'login_motpasseoublie' => 'ankouaet&nbsp;ho&nbsp;ker-tremen&nbsp;ganeoc\'h&nbsp;?',
'login_non_securise' => 'Diwallit, n\'eo ket suraet ar furmskrid-ma&ntilde;.
   Ma ne fell ket deoc\'h e c\'hellfe ho ker-tremen beza&ntilde; pesketet
   war ar rouedad, gweredekait Javascript en ho merdeer ha',
'login_nouvelle_tentative' => 'Klask en-dro',
'login_par_ici' => 'Enrollet oc\'h...dre ama&ntilde;...',
'login_pass2' => 'Ger-tremen&nbsp;:',
'login_preferez_refuser' => '<b>Ma kavit gwell nac\'ha&ntilde; an toupino&ugrave;</b>, e c\'hellit ober gant un doare all da gevrea&ntilde;, met n\'eo ket ken asur&nbsp;:',
'login_recharger' => 'adkarga&ntilde; ar bajenn-ma&ntilde;',
'login_rester_identifie' => 'Chom anavezet un nebeud devezhio&ugrave;',
'login_retour_public' => 'Distrei&ntilde; d\'al lodenn foran',
'login_retour_site' => 'Distrei&ntilde; d\'al lodenn foran',
'login_retoursitepublic' => 'distrei&ntilde;&nbsp;d\'al&nbsp;lodenn&nbsp;foran',
'login_sans_cookiie' => 'Kevrea&ntilde; hep toupino&ugrave;',
'login_securise' => 'Login s&eacute;curis&eacute;', # NEW
'login_sinscrire' => 'en em enskriva&ntilde;',
'login_test_navigateur' => 'taol-arnod merdeer/adkevrea&ntilde;',
'login_verifiez_navigateur' => '(Gwiriit memes tra n\'eo ket bet memoret ho ker-tremen gant ar merdeer...)',

// M
'masquer_colonne' => 'Kuzhat ar bann-ma&ntilde;',
'masquer_trad' => 'kuzhat an troidigezhio&ugrave;',
'module_fichiers_langues' => 'Restro&ugrave; yezh',

// N
'navigateur_pas_redirige' => 'Klikit ama&ntilde; evit kederc\'hel ma ne vez ket adhe&ntilde;chet ho merdeer.',
'numero' => 'Niverenn',

// O
'occurence' => 'Kavadenn',
'onglet_affacer_base' => 'Diverka&ntilde; an diaz',
'onglet_auteur' => 'Ar skridaozer',
'onglet_contenu_site' => 'Endalc\'had al lec\'hienn',
'onglet_evolution_visite_mod' => 'Emdroadur',
'onglet_fonctions_avances' => 'Arc\'hwelio&ugrave; kemplezh',
'onglet_informations_personnelles' => 'Titouro&ugrave; hiniennel',
'onglet_interactivite' => 'Etreobererezh',
'onglet_messagerie' => 'Postelerezh',
'onglet_messages_internes' => 'Kemennadenno&ugrave; diabarzh',
'onglet_messages_publics' => 'Kemennadenno&ugrave; foran',
'onglet_messages_vide' => 'kemennadenno&ugrave; hep testenn',
'onglet_origine_visites' => 'Orin ar gweladenno&ugrave;',
'onglet_repartition_debut' => 'abaoe an dero&ugrave;',
'onglet_repartition_lang' => 'Dasparzh diouzh ar yezh',
'onglet_repartition_rubrique' => 'Dasparzh diouzh ar rummad',
'onglet_save_restaur_base' => 'Savetei&ntilde;/Assevel an diaz',
'onglet_vider_cache' => 'Goullonderi&ntilde; ar grubuilh',

// P
'pass_choix_pass' => 'Dibabit ho ker-tremen nevez :',
'pass_erreur' => 'Fazi',
'pass_erreur_acces_refuse' => '<b>Fazi :</b> n\'hoc\'h ket aotreet da zont war al lec\'hienn-ma&ntilde; ken.',
'pass_erreur_code_inconnu' => '<b>Fazi :</b> ne glot ar c\'hod-ma&ntilde; gant gweladenner ebet a c\'hall mont war al lec\'hienn-ma&ntilde;.',
'pass_erreur_non_enregistre' => '<b>Fazi :</b>n\'eo ket enrollet ar chomlec\'h <tt>@email_oubli@</tt> war al lec\'hienn-ma&ntilde;.',
'pass_erreur_non_valide' => '<b>Fazi :</b> n\'eo ket reizh ar postel <tt>@email_oubli@</tt> !',
'pass_erreur_probleme_technique' => '<b>Fazi :</b> abalamout d\'u gudenn deknikel, ne c\'hell ket ar postel beza&ntilde; kaset.',
'pass_espace_prive_bla' => 'Dav eo beza&ntilde; enskrivet a-raok gallout tizhout lodenn brevez al lec\'hienn.
  P aviot enrollet e c\'hellot lenn ar pennado&ugrave; meeur o skriva&ntilde;, kinnig pennado&ugrave;, ha kemer perzh er foromo&ugrave;.',
'pass_forum_bla' => 'Goulennet hoc\'h eus gallout kemer perzh war ur forom n\'hall nemet an implijerien enrollet skriva&ntilde; warna&ntilde;.',
'pass_indiquez_cidessous' => 'Skrivit ama&ntilde; dindan ar postel a oa bet implijet ganeoc\'h evit en em enrolla&ntilde;.
   Ur postel a vo kaset deoc\'h enna&ntilde; an titouro&ugrave; ret evit gallout dont en-dro war al lec\'hienn.',
'pass_mail_passcookie' => '(ur gemennadenn emgefre eo homa&ntilde;)
Evit gallout distrei&ntilde; war al lec\'hienn
@nom_site_spip@ (@adresse_site@)

Kit d\'ar chomlec\'h-ma&ntilde; :

    @sendcookie@

Neuze e c\'hellot merka&ntilde; ur ger-tremen nevez ha
kevrea&ntilde; en-dro ouzh al lec\'hienn.

', # Connecter : gwelloc'h eo ober gant kevrea&ntilde; zo muioc'h en implij gant an dud. Kevrea&ntilde; ouzh ar genrouedad hag all.
'pass_mot_oublie' => 'Ankouaet ar ger-tremen',
'pass_nouveau_enregistre' => 'Enrollet eo bet ho ker-tremen nevez.',
'pass_nouveau_pass' => 'Ger-tremen nevez',
'pass_ok' => 'MAT EO',
'pass_oubli_mot' => 'Ankouaet ar ger-tremen',
'pass_quitter_fenetre' => 'Kuitaat ar prenestr-ma&ntilde;',
'pass_rappel_login' => 'Dalc\'hit so&ntilde;j : &laquo; @login@ &raquo; eo ho anv-tremen (login).',
'pass_recevoir_mail' => 'Ur postel a vo kaset deoc\'h, enna&ntilde; an titouro&ugrave; ret da c\'hallout tizhout al lec\'hienn en-dro.',
'pass_retour_public' => 'Distrei&ntilde; d\'al lodenn foran',
'pass_rien_a_faire_ici' => 'Netra d\'ober ama&ntilde;.',
'pass_vousinscrire' => 'En em enskriva&ntilde; war al lec\'hienn-ma&ntilde;',
'precedent' => 'kent',
'previsualisation' => 'Rakwelet',
'previsualiser' => 'Rakwelet',

// R
'retour' => 'Distrei&ntilde;',

// S
'spip_conforme_dtd' => 'SPIP a gav dezha&ntilde; e klot an teul-ma&ntilde; gant e DOCTYPE :',
'squelette' => 'framm',
'squelette_inclus_ligne' => 'framm e-barzh, linenn',
'squelette_ligne' => 'framm, linenn',
'stats_visites_et_popularite' => '@visites@ gweladenn&nbsp;; brud;&nbsp;: @popularite@',
'suivant' => 'war-lerc\'h',

// T
'taille_ko' => '@taille@&nbsp;ke',
'taille_mo' => '@taille@&nbsp;Me',
'taille_octets' => '@taille@&nbsp;eizhbit',
'texte_actualite_site_1' => 'Pa viot boas ouzh an etrefas e c\'hellot klika&ntilde; war &laquo;',
'texte_actualite_site_2' => 'etrefas klok',
'texte_actualite_site_3' => '&raquo; evit sevijo&ugrave; ouzhpenn.',
'texte_creation_automatique_vignette' => 'Ober a reer gant ar sevel skeudennigo&ugrave; adal skeudenno&ugrave;. Ma stailhi skeudenno&ugrave; er furmad(o&ugrave;) @gd_formats@, adal ar furmskrid-ma&ntilde; e vo staget ur skeudennig @taille_preview@&nbsp;piksel d\'ar muia&ntilde; outo.',
'texte_documents_associes' => 'Stag eo an teulio&ugrave;-ma&ntilde; ouzh ar pennad,
    met n\'int ket bet ensoc\'het diouzhtu enna&ntilde;
    Diouzh mod pajennaoza&ntilde; al lec\'hienn e c\'hellint beza&ntilde; diskouezet dindan stumm restro&ugrave; stag.',
'texte_erreur_mise_niveau_base' => 'Ur fazi zo bet gant an diaz titouro&ugrave; en ur hizivaat.
  N\'eo ket tremenet ar skeudenn <b>@fichier@</b> (pennad @id_article@).
  Notennit an daveenn-se, klaksit hizivaat en-dro, 
  ha gwiriit e vez diskouezet ar skeudenno&ugrave; er pennado&ugrave;.',
'texte_erreur_visiteur' => 'Klasket hoc\'h eus tizhout al lodenn brevez gant un anv implijer direizh.',
'texte_inc_auth_1' => 'Enrollet oc\'h dindan al ger kevrea&ntilde;
 <b>@auth_login@</b>, met n\'eus ket anezha&ntilde; (ken) en diaz titouro&ugrave;.
  Klaskit ',
'texte_inc_auth_2' => 'adkevrea&ntilde;',
'texte_inc_auth_3' => ', goude beza&ntilde; kuitaet hag adloc\'het ho merdeer.',
'texte_inc_config' => '>Ul levezon vras o deus kemmo&ugrave; ar bajenn-ma&ntilde; war mont en-dro hollek al lec\'hienn.
Aliet oc\'h da chom hep kemma&ntilde; tra ebet e-keit ha n\'oc\'h ket boas ouzh SPIP.
 <br /><br /><b>Aliet oc\'h da lezel webmestr penna&ntilde; al lec\'hienn ober war-dro ar pajenno&ugrave;-ma&ntilde;.</b>',
'texte_inc_meta_1' => 'Ur fazi zo bet en ur skriva&ntilde; war ar restr <code>@fichier@</code>. Dre ma\'z oc\'h merour al lec\'hienn e rankit ',
'texte_inc_meta_2' => 'Gwiria&ntilde; ar gwirio&ugrave; da skriva&ntilde; ',
'texte_inc_meta_3' => 'war ar c\'havlec\'h <code>@repertoire@</code>.',
'texte_statut_en_cours_redaction' => 'o skridaoza&ntilde;',
'texte_statut_poubelle' => 'er pod-lastez',
'texte_statut_propose_evaluation' => 'kinniget ouzh an amprou',
'texte_statut_publie' => 'embannet',
'texte_statut_refuse' => 'nac\'het',
'titre_ajouter_mot_cle' => 'OUZHPENNA&Ntilde; UR GER-STUR :',
'titre_breve_proposee' => 'Berrskrid bet kinniget',
'titre_breve_publiee' => 'Berrskrid bet embannet',
'titre_breve_refusee' => 'Berrskrid bet nac\'het',
'titre_cadre_raccourcis' => 'BERRADENNO&Ugrave; :',
'titre_changer_couleur_interface' => 'Kemm liv an etrefas',
'titre_forum' => 'Forom',
'titre_image_admin_article' => 'Gallout a rit mera&ntilde; ar pennad-ma&ntilde;',
'titre_image_administrateur' => 'Merour',
'titre_image_aide' => 'Skoazell diwar-benn an elfenn-ma&ntilde;',
'titre_image_auteur_supprime' => 'Skridaozer bet diverket',
'titre_image_redacteur' => 'Skridaozer hep aotre moned',
'titre_image_redacteur_02' => 'Skridaozer',
'titre_image_visiteur' => 'Gweladenner',
'titre_joindre_document' => 'STAGA&Ntilde; UN TEUL',
'titre_liens_entrants' => 'Liammo&ugrave; davet al lec\'hienn',
'titre_mots_cles' => 'GERIO&Ugrave;-STUR',
'titre_probleme_technique' => 'Diwallit&nbsp;: abalamour d\'ur gudenn deknikel (servijer SQL), n\'eus ket tu da dizhout al lodenn-ma&ntilde; eus al lec\'hienn. Trugarez evit ho komprenezon.',
'titre_publier_document' => 'EMBANN UN TEUL ER RUBRIKENN-MA&Ntilde;',
'titre_signatures_attente' => 'Sinadurio&ugrave; a c\'hortoz beza&ntilde; kadarnaet',
'titre_signatures_confirmees' => 'Sinadurio&ugrave; bet gwiriekaet',
'titre_statistiques' => 'Stadego&ugrave; al lec\'hienn', # Stadego&ugrave;, termen skoueriekaet gant TermBret evit Statistiques.
'titre_titre_document' => 'Titl an teul&nbsp;:',
'todo' => 'da zont',
'trad_reference' => '(pennad orin)',

// Z
'zbug_balise_b_aval' => '&nbsp;: balizenn B en ardrao&ntilde;',
'zbug_balise_inexistante' => 'Diskl&ecirc;riet-fall eo ar valizenn @balise@ evit @from@',
'zbug_balise_sans_argument' => 'Un arguzenn a vank er valizenn @balise@',
'zbug_boucle' => 'bouklenn',
'zbug_boucle_recursive_undef' => 'N\'eo ket bet termenet ar vouklenn-ma&ntilde; : @nom@',
'zbug_calcul' => 'jedi&ntilde;',
'zbug_champ_hors_boucle' => 'Maezienn @champ@ e diavaez ar vouklenn',
'zbug_champ_hors_motif' => 'Maezienn @champ@ er-maez kendestenn @motif@',
'zbug_code' => 'kod',
'zbug_critere_inconnu' => 'Dezverk @critere@ dianav',
'zbug_distant_interdit' => 'N\'eo ket posupl war un diaz roado&ugrave; diavaez',
'zbug_doublon_table_sans_cle_primaire' => 'Doublenno&ugrave; war un diaz hep alc\'hwez kenta&ntilde; atomek',
'zbug_doublon_table_sans_index' => 'Doublenn war un diaz hep meneger',
'zbug_erreur_boucle_double' => 'Bouklenn @id@ bet termenet div wech',
'zbug_erreur_boucle_fermant' => 'Chomet eo digor ar vouklenn @id@',
'zbug_erreur_boucle_syntaxe' => 'Direizh eo ereadurezh  ar vouklenn  @id@',
'zbug_erreur_compilation' => 'Fazi kempuna&ntilde;',
'zbug_erreur_execution_page' => 'Fazi erounit',
'zbug_erreur_filtre' => 'Sil @filtre@ didermenet',
'zbug_erreur_meme_parent' => 'n\'hall an dezverk {meme_parent} beza&ntilde; implijet nemet war ar bouklenno&ugrave; (FOROMO&Ugrave;) pe (RUBRIKENNO&Ugrave;)',
'zbug_erreur_squelette' => 'Fazi(o&ugrave;) er framm',
'zbug_hors_compilation' => 'Er-maez kempunad',
'zbug_info_erreur_squelette' => 'Fazi war al lec\'hienn',
'zbug_inversion_ordre_inexistant' => 'Eilpenna&ntilde; un urzh n\'eus ket anezha&ntilde;',
'zbug_pagination_sans_critere' => 'N\'eus dezverk ebet d\'ar valizenn #PAJENNAOUI&Ntilde;, pe neuze eo implijet en ur vouken a dro warni hec\'h-unan',
'zbug_parametres_inclus_incorrects' => 'Direizh eo an arventenn ensoc\'ha&ntilde; @param@',
'zbug_profile' => 'Amzer jedi&ntilde;&nbsp;: @time@',
'zbug_resultat' => 'disoc\'h',
'zbug_serveur_indefini' => 'Servijer SQL didermenet',
'zbug_statistiques' => 'Stadego&ugrave; ar goulenno&ugrave; SQL urzhiet diouzh o fad',
'zbug_table_inconnue' => 'Taolenn SQL &laquo; @table@ &raquo; dianav',
'zxml_connus_attributs' => 'perzhio&ugrave; anavezet',
'zxml_de' => 'da',
'zxml_inconnu_attribut' => 'perzh dianav',
'zxml_inconnu_balise' => 'balizenn dianav',
'zxml_inconnu_entite' => 'elfenn dianav',
'zxml_inconnu_id' => 'ID dianav',
'zxml_mais_de' => 'met eus',
'zxml_non_conforme' => 'ne glot ket gant an abeg',
'zxml_non_fils' => 'n\'eo ket ur mab da',
'zxml_nonvide_balise' => 'balizenn ket goullo',
'zxml_obligatoire_attribut' => 'perzh rediet, met na gaver ket e',
'zxml_succession_fils_incorrecte' => 'heuliad ar vibien direizh',
'zxml_survoler' => 'tremen buan da welet ar re zo reizh',
'zxml_valeur_attribut' => 'talvoudegezh ar perzh',
'zxml_vide_balise' => 'balizenn c\'houllo',
'zxml_vu' => 'bet gwelet a-raok'
);

?>
